<?php
/**
 * Copyright ©  All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Pinpoint\CarouselManager\Model;

use Magento\Framework\Api\DataObjectHelper;
use Pinpoint\CarouselManager\Api\Data\SlideInterface;
use Pinpoint\CarouselManager\Api\Data\SlideInterfaceFactory;

class Slide extends \Magento\Framework\Model\AbstractModel
{

    protected $slideDataFactory;

    protected $dataObjectHelper;

    protected $_eventPrefix = 'pinpoint_carouselmanager_slide';
    /**
     * @var SlideCtaRepository
     */
    private $slideCtaRepository;

    /**
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param SlideInterfaceFactory $slideDataFactory
     * @param DataObjectHelper $dataObjectHelper
     * @param \Pinpoint\CarouselManager\Model\ResourceModel\Slide $resource
     * @param \Pinpoint\CarouselManager\Model\ResourceModel\Slide\Collection $resourceCollection
     * @param SlideCtaRepository $slideCtaRepository
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        SlideInterfaceFactory $slideDataFactory,
        DataObjectHelper $dataObjectHelper,
        \Pinpoint\CarouselManager\Model\ResourceModel\Slide $resource,
        \Pinpoint\CarouselManager\Model\ResourceModel\Slide\Collection $resourceCollection,
        SlideCtaRepository $slideCtaRepository,
        array $data = []
    ) {
        $this->slideDataFactory = $slideDataFactory;
        $this->slideCtaRepository = $slideCtaRepository;
        $this->dataObjectHelper = $dataObjectHelper;
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * Retrieve slide model with slide data
     * @return SlideInterface
     */
    public function getDataModel()
    {
        $slideData = $this->getData();

        $slideDataObject = $this->slideDataFactory->create();
        $this->dataObjectHelper->populateWithArray(
            $slideDataObject,
            $slideData,
            SlideInterface::class
        );

        return $slideDataObject;
    }

    public function getIdentifier()
    {
        return 'slide_' . $this->getId();
    }

    public function getCtas()
    {
        return $this->slideCtaRepository->getBySlideId($this->getId());
    }
}

